@@ -28,7 +28,7 @@ class MachineLearningModel(object):
         #     message = f"Machine learning model at {path} not exists!"
         #     logger.error(message)
         #     raise FileNotFoundError(message)
-        path = read_text("./ml/model/", "TrainedModel_c++.ann")
+        path = read_text("ml.model", "TrainedModel_c++.ann")
         self.load_model(path)
     
     def load_model(self, path : str):
